from sqlmodel import Session, create_engine, select

from app import crud
from app.core.config import settings
from app.models import User, UserCreate, Setting, SettingBase, SettingCreate

engine = create_engine(str(settings.SQLALCHEMY_DATABASE_URI))


# make sure all SQLModel models are imported (app.models) before initializing DB
# otherwise, SQLModel might fail to initialize relationships properly
# for more details: https://github.com/fastapi/full-stack-fastapi-template/issues/28


def init_db(session: Session) -> None:
    # Tables should be created with Alembic migrations
    # But if you don't want to use migrations, create
    # the tables un-commenting the next lines
    # from sqlmodel import SQLModel

    # from app.core.engine import engine
    # This works because the models are already imported and registered from app.models
    # SQLModel.metadata.create_all(engine)

    user = session.exec(
        select(User).where(User.email == settings.FIRST_SUPERUSER)
    ).first()
    if not user:
        user_in = UserCreate(
            email=settings.FIRST_SUPERUSER,
            password=settings.FIRST_SUPERUSER_PASSWORD,
            is_superuser=True,
        )
        user = crud.create_user(session=session, user_create=user_in)

    setting = session.exec(select(Setting)).first()
    if not setting:
        setting_in = SettingCreate(
            address = "now is empty",
            phone = "now is empty",
            email = "now is empty",
            facebook = "now is empty",
            instagram = "now is empty",
            youtube = "now is empty",
            youtube_link = "now is empty",
            whatsapp = "now is empty",
            google_map_api_key = "now is empty",
            latitude = 0,
            longitude = 0,
            
        )
        setting = crud.create_settings(session=session, setting_in=setting_in)
